var searchData=
[
  ['g',['g',['../structplplot_1_1__N9.html#ac6f4b924e5b670191775937095230225',1,'plplot::_N9::g()'],['../structPLColor.html#ab71f4093766e02ce796389832582517a',1,'PLColor::g()']]],
  ['g_5fweinitializedwx',['g_weInitializedWx',['../wxwidgets_8cpp.html#a7124994185e3dab65cde4f58ec99f7a1',1,'wxwidgets.cpp']]],
  ['gbox',['gbox',['../plframe_8c.html#a9595025f37f8241c8998ed9bf0d981fd',1,'gbox(PLFLT *, PLFLT *, PLFLT *, PLFLT *, const char **):&#160;plframe.c'],['../plplotter_8c.html#a67b7f7268575a49cc5cd8eca75d0a44d',1,'gbox(PLFLT *, PLFLT *, PLFLT *, PLFLT *, CONST char **):&#160;plplotter.c']]],
  ['gc',['gc',['../structTkwDev.html#a8166e22ee1368fcea258b52224ef1878',1,'TkwDev::gc()'],['../structXwDev.html#a5476a3dc986ba91f5491f7e9f63e3ae1',1,'XwDev::gc()']]],
  ['gchr',['gchr',['../classplstream.html#ae7efc7ade952636c6abe4aa0f7d4546a',1,'plstream']]],
  ['gcmap1_5frange',['gcmap1_range',['../classplstream.html#ad33d6f819a27a64e0f78458bcee80064',1,'plstream']]],
  ['gcol0',['gcol0',['../classplstream.html#aba4cd52aa9af674333751cfd4c3e1f0e',1,'plstream']]],
  ['gcol0a',['gcol0a',['../classplstream.html#ae03112e488b0c59a977e82d0393b8432',1,'plstream']]],
  ['gcolbg',['gcolbg',['../classplstream.html#a3c25068052fb61248d1628384fd742ec',1,'plstream']]],
  ['gcolbga',['gcolbga',['../classplstream.html#a6f104110f4ec0c354ef1d936b0191cc7',1,'plstream']]],
  ['gcompression',['gcompression',['../classplstream.html#af31ea9050a284ecb3ee79f5a789008bf',1,'plstream']]],
  ['gcxor',['gcXor',['../structTkwDisplay.html#a31baa71129de5785caaa7f5dbd2fc2bb',1,'TkwDisplay::gcXor()'],['../structXwDisplay.html#ad215e4872240e5a3464a7591aa608ac1',1,'XwDisplay::gcXor()']]],
  ['gd_2ec',['gd.c',['../gd_8c.html',1,'']]],
  ['gdev',['gdev',['../classplstream.html#a85190181cec5e69ef8c45a50d6b0cbf0',1,'plstream']]],
  ['gdidev',['gdidev',['../classplstream.html#a97bd87e7d140e103e6788c5469e7c429',1,'plstream']]],
  ['gdiori',['gdiori',['../classplstream.html#a33846a59b77a7ec421632667fb4a6077',1,'plstream']]],
  ['gdiplt',['gdiplt',['../classplstream.html#a115a82090b4005cba6c4603e3db014fe',1,'plstream']]],
  ['gedouble',['gedouble',['../bhunt__search__test_8c.html#a9f937269e10b4b02cfc3743ce8740b95',1,'bhunt_search_test.c']]],
  ['gemjdtime_5ftai',['geMJDtime_TAI',['../qsastime_8c.html#a7659de70954c92b8c19d43785c265c06',1,'qsastime.c']]],
  ['gemjdtime_5futc',['geMJDtime_UTC',['../qsastime_8c.html#acc0692539df981d46f8e64f03cfbf2b5',1,'qsastime.c']]],
  ['genlin',['genlin',['../plline_8c.html#a57ad09cf22b7982a6f800d9458c5cb88',1,'plline.c']]],
  ['genrand_5fint31',['genrand_int31',['../mt19937ar_8c.html#a6339fb46fb539f173518a6367f6616bd',1,'genrand_int31(void):&#160;mt19937ar.c'],['../mt19937ar_8h.html#a6339fb46fb539f173518a6367f6616bd',1,'genrand_int31(void):&#160;mt19937ar.c']]],
  ['genrand_5fint32',['genrand_int32',['../mt19937ar_8c.html#a2b30ec504bc40c51320d14da9dfab43b',1,'genrand_int32(void):&#160;mt19937ar.c'],['../mt19937ar_8h.html#a2b30ec504bc40c51320d14da9dfab43b',1,'genrand_int32(void):&#160;mt19937ar.c']]],
  ['genrand_5freal1',['genrand_real1',['../mt19937ar_8c.html#ac94ab75771800274ed1a2bedeca86f04',1,'genrand_real1(void):&#160;mt19937ar.c'],['../mt19937ar_8h.html#ac94ab75771800274ed1a2bedeca86f04',1,'genrand_real1(void):&#160;mt19937ar.c']]],
  ['genrand_5freal2',['genrand_real2',['../mt19937ar_8c.html#a4ee58afbdf91669ff8a15fc19e627bea',1,'genrand_real2(void):&#160;mt19937ar.c'],['../mt19937ar_8h.html#a4ee58afbdf91669ff8a15fc19e627bea',1,'genrand_real2(void):&#160;mt19937ar.c']]],
  ['genrand_5freal3',['genrand_real3',['../mt19937ar_8c.html#ab1a90aa68ebfcd712cb05ed9061ecf44',1,'genrand_real3(void):&#160;mt19937ar.c'],['../mt19937ar_8h.html#ab1a90aa68ebfcd712cb05ed9061ecf44',1,'genrand_real3(void):&#160;mt19937ar.c']]],
  ['genrand_5fres53',['genrand_res53',['../mt19937ar_8c.html#ac821d41970276e53e85bde08b24536b8',1,'genrand_res53(void):&#160;mt19937ar.c'],['../mt19937ar_8h.html#ac821d41970276e53e85bde08b24536b8',1,'genrand_res53(void):&#160;mt19937ar.c']]],
  ['geometry',['geometry',['../structPLStream.html#a7844488c645193fee1f5e1f31df9798e',1,'PLStream::geometry()'],['../tkMain_8c.html#a3512ed15de220f178dc26334564c6463',1,'geometry():&#160;tkMain.c']]],
  ['gesc',['gesc',['../classplstream.html#a4cdd16f2533213fef5cd5d18358af469',1,'plstream']]],
  ['get',['get',['../structtclMatrix.html#a1f07da9a87e675b7349e09253dcafbce',1,'tclMatrix::get()'],['../structplf2ops__t.html#a3d2ca85ae97972e8b4d6e0221aaedc27',1,'plf2ops_t::get()'],['../structswig__lua__var__info.html#a56fb0b689f37015e340b35c6d7ee0b99',1,'swig_lua_var_info::get()']]],
  ['get_5fattr',['get_attr',['../structswig__globalvar.html#ab617d0ca02f7660a9e5fd31dceaf6475',1,'swig_globalvar']]],
  ['get_5fcharacter_5for_5fsymbol_5fheight',['get_character_or_symbol_height',['../pllegend_8c.html#aec07c6350dac714def00998097602825',1,'pllegend.c']]],
  ['get_5fcursor',['get_cursor',['../aqt_8c.html#a283273d4ad67a6e5f6d701232243fde8',1,'aqt.c']]],
  ['get_5ffont',['get_font',['../ps_8c.html#a2c1f6499446d1f656afb4e58422467d3',1,'ps.c']]],
  ['get_5fline_5fproperties',['get_line_properties',['../cairo_8c.html#a6fd98a3dd9c44e539ca2bcaf5fe15e8a',1,'cairo.c']]],
  ['get_5fmethod',['get_method',['../structswig__octave__member.html#afc6d3dc3d5c938d5a29f53fb7237ea5a',1,'swig_octave_member']]],
  ['get_5fml_5fdefined_5ffunc',['get_ml_defined_func',['../plplot__impl_8c.html#ad6a6ceeee3ec4d3e2ef899f7547add3b',1,'plplot_impl.c']]],
  ['get_5fml_5fmapform_5ffunc',['get_ml_mapform_func',['../plplot__impl_8c.html#a7244ea838f77b6bd5ff4f343862c4214',1,'plplot_impl.c']]],
  ['get_5fml_5fplotter_5ffunc',['get_ml_plotter_func',['../plplot__impl_8c.html#aff49a95f82ee900861be816b4a1ba580',1,'plplot_impl.c']]],
  ['get_5fmode',['get_mode',['../cairo_8c.html#a9e55fca8c85f59c5f4ad2be0b5f6e608',1,'cairo.c']]],
  ['get_5fncoords',['get_ncoords',['../plr_8c.html#ae58b9982d2450cb06989402afaaefac9',1,'plr.c']]],
  ['get_5fptr',['get_ptr',['../classoctave__swig__ref.html#ade76da447bc44120acbed8fda510bbde',1,'octave_swig_ref']]],
  ['get_5fstring_5flength',['get_string_length',['../structPLStream.html#a97ec49d30120b332e4f9246019bc9800',1,'PLStream']]],
  ['get_5fsubpage_5fper_5fmm',['get_subpage_per_mm',['../pllegend_8c.html#a0b06baad6dbba8da07252a12887eb264',1,'pllegend.c']]],
  ['get_5ftmpdir_5flist',['get_tmpdir_list',['../plstdio_8c.html#ad77dd0fafc6ef3e40bc40cd70988e843',1,'plstdio.c']]],
  ['getbuffer',['getBuffer',['../classPLMemoryMap.html#ade883f13245aa2793a4944d2091e531a',1,'PLMemoryMap']]],
  ['getcdfepoch',['getCDFepoch',['../qsastime__extra_8c.html#ad5ae2c0c56aea86ccae7450878bc57ff',1,'getCDFepoch(MJDtime *MJD):&#160;qsastime_extra.c'],['../qsastime__extra_8h.html#af357f4ded572e4f8648b5b92b17b67b1',1,'getCDFepoch(MJDtime *MJD):&#160;qsastime_extra.c']]],
  ['getclipregion',['GetClipRegion',['../classwxPLDevice.html#a2de09de3f0472d8305ece1b8cd2f123c',1,'wxPLDevice']]],
  ['getcursor',['GetCursor',['../classplstream.html#a1ec36e604b750ef5b72a562b31a001f6',1,'plstream']]],
  ['getdayofweek',['getDayOfWeek',['../qsastime_8c.html#ac81cf24972f4842215d9c908116699f5',1,'getDayOfWeek(const MJDtime *MJD):&#160;qsastime.c'],['../qsastimeP_8h.html#ab428dd925e265c31755d572c9b79f867',1,'getDayOfWeek(const MJDtime *MJD):&#160;qsastime.c']]],
  ['getdiffdays',['getDiffDays',['../qsastime__extra_8c.html#a3a2386ce303e6e23bc9874357c63b661',1,'getDiffDays(MJDtime *MJD1, MJDtime *MJD2):&#160;qsastime_extra.c'],['../qsastime__extra_8h.html#a0d34b04119c9aea514bc2ca4ddcc3c19',1,'getDiffDays(MJDtime *MJD1, MJDtime *MJD2):&#160;qsastime_extra.c']]],
  ['getdiffsecs',['getDiffSecs',['../qsastime__extra_8c.html#a88513dd1ed5052962e2673c7bb1d795b',1,'getDiffSecs(MJDtime *MJD1, MJDtime *MJD2):&#160;qsastime_extra.c'],['../qsastime__extra_8h.html#aebe42446e2eccd74de3642bff4d7b598',1,'getDiffSecs(MJDtime *MJD1, MJDtime *MJD2):&#160;qsastime_extra.c']]],
  ['getentries',['GetEntries',['../tclAPI_8c.html#ac277fc1a34456aa0621c7692d08163b9',1,'tclAPI.c']]],
  ['getfci',['getFci',['../classFont.html#a16e39a83e4dcbad4f51c86058c072719',1,'Font']]],
  ['getflt',['GetFlt',['../classplstream.html#a54d547e04f4085121c578812f1d08d73',1,'plstream']]],
  ['getfont',['getFont',['../classQtPLDriver.html#af6aa0701912852005242921dc1442692',1,'QtPLDriver::getFont()'],['../classFontGrabber.html#aa5d8a0c836830353b6ba3dd087a2bc82',1,'FontGrabber::GetFont()']]],
  ['getint',['GetInt',['../classplstream.html#a4209524d70561e0054aa26e5b72ec015',1,'plstream']]],
  ['getisostring',['getISOString',['../qsastime__extra_8c.html#a18f69f8819a7d88656b4282b836e5661',1,'getISOString(MJDtime *MJD, int delim, int forceJulian):&#160;qsastime_extra.c'],['../qsastime__extra_8h.html#afc7d4c59c22310fd34e4abf593397d41',1,'getISOString(MJDtime *MJD, int delim, int forceJulian):&#160;qsastime_extra.c']]],
  ['getjd',['getJD',['../qsastime__extra_8c.html#a9f4ba0f2368287c745120b6b203404da',1,'getJD(MJDtime *MJD):&#160;qsastime_extra.c'],['../qsastime__extra_8h.html#ab7aa2822452eccd54460687c944c0d39',1,'getJD(MJDtime *MJD):&#160;qsastime_extra.c']]],
  ['getlongdayofweek',['getLongDayOfWeek',['../qsastime_8c.html#a10ee0850b29aa1c2de5136714c535121',1,'getLongDayOfWeek(const MJDtime *MJD):&#160;qsastime.c'],['../qsastimeP_8h.html#a5b76f7b77c39d4560337579d57073ec7',1,'getLongDayOfWeek(const MJDtime *MJD):&#160;qsastime.c']]],
  ['getlongmonth',['getLongMonth',['../qsastime_8c.html#a9433a99f28dc903d4eb97e6b9911f953',1,'getLongMonth(int m):&#160;qsastime.c'],['../qsastimeP_8h.html#afbc41ff79387eabce61bf0132b4786b7',1,'getLongMonth(int m):&#160;qsastime.c']]],
  ['getmethod',['getmethod',['../structswig__lua__attribute.html#ab18a92c81433b7b3de23856cda4b89b5',1,'swig_lua_attribute']]],
  ['getmjd',['getMJD',['../qsastime__extra_8c.html#a3cd6abe9417edd7f0c777d9fd4c24475',1,'getMJD(MJDtime *MJD):&#160;qsastime_extra.c'],['../qsastime__extra_8h.html#a2bef0b5415bc6912ba15a8eb35160f1f',1,'getMJD(MJDtime *MJD):&#160;qsastime_extra.c']]],
  ['getmonth',['getMonth',['../qsastime_8c.html#abd41112517c181424c476bd0469ac728',1,'getMonth(int m):&#160;qsastime.c'],['../qsastimeP_8h.html#a2574e380fe47645e34dcf7792d3b8bf1',1,'getMonth(int m):&#160;qsastime.c']]],
  ['getname',['GetName',['../classplstream.html#a873c02ff3dcaa3b56633f9eeeee92b9e',1,'plstream']]],
  ['getoptarg',['GetOptarg',['../plargs_8c.html#a4c5db4585b13da0514f1bb55231bec31',1,'plargs.c']]],
  ['getsize',['getSize',['../classFont.html#a91ec5bc2045ad4cb4c02598d8c1a9164',1,'Font::getSize()'],['../classPLMemoryMap.html#a63d96bc4208678d6b9f0289140fbce50',1,'PLMemoryMap::getSize()']]],
  ['getsquares',['getsquares',['../csa_8c.html#af7faa5d6360bdf5ae2fee6a9febd4ea3',1,'csa.c']]],
  ['getstream',['GetStream',['../classwxPLplotwindow.html#ad9d61ecc3ec9276be73cc89ce7a1b1aa',1,'wxPLplotwindow']]],
  ['gettextpicture',['getTextPicture',['../classQtPLDriver.html#a6ba3d708c1155e63468b51c010466d12',1,'QtPLDriver']]],
  ['getunderlined',['getUnderlined',['../classFont.html#aed3932c16a226bcfea6fa43edc9f5c97',1,'Font']]],
  ['getwxfont',['getWxFont',['../classFont.html#a4ee204fe1ad6485a43c572146f741c92',1,'Font']]],
  ['getyad',['getYAD',['../qsastime_8c.html#a3b5af20594b02a640ef7f8422ad29b12',1,'getYAD(int *year, int *ifleapyear, int *doy, const MJDtime *MJD, int forceJulian):&#160;qsastime.c'],['../qsastimeP_8h.html#a5e4bad0354598a5b258808c41b2d8d59',1,'getYAD(int *year, int *ifleapyear, int *doy, const MJDtime *MJD, int forceJulian):&#160;qsastime.c']]],
  ['gfam',['gfam',['../classplstream.html#a61a18d3cdbcbfad10cb2ced205eae617',1,'plstream']]],
  ['gfci',['gfci',['../classplstream.html#a96589d5dc58d4a7b63cc9fc910150440',1,'plstream']]],
  ['gfile',['gfile',['../classplstream.html#ab8862567a9344df489af0c51ebd4ab1f',1,'plstream']]],
  ['gfiledevs',['gFileDevs',['../classplstream.html#a7b9ec1864a7a454798b2d0e994882669',1,'plstream']]],
  ['gfnam',['gfnam',['../classplstream.html#a420b0cbe7c028e24a8508b839ce4f2d0',1,'plstream']]],
  ['gfont',['gfont',['../classplstream.html#a3d928d926a52599f434642f294961a39',1,'plstream']]],
  ['gin',['gin',['../structTkDev.html#a5dd032b995b9dbc11f687137e8a789d1',1,'TkDev::gin()'],['../structTkwDev.html#af1b4162860b1d4ba0850ae4ee3a5b583',1,'TkwDev::gin()'],['../structXwDev.html#ad563957b570e07fb4ff157e1082ad7f6',1,'XwDev::gin()']]],
  ['glevel',['glevel',['../classplstream.html#ac6f30d556bf27fc3a4f572808cad2535',1,'plstream']]],
  ['gpage',['gpage',['../classplstream.html#af818bf6334ccc57869c1c5f73a416b23',1,'plstream']]],
  ['gra',['gra',['../classplstream.html#a4551fd19d5f4d061bf82a1444ba5c4f4',1,'plstream']]],
  ['gradient',['gradient',['../classplstream.html#a5c09f493eec498254acb351baab2ef4a',1,'plstream::gradient()'],['../cairo_8c.html#a38b79c8a32ba49b454f9d69ecd0b31b2',1,'gradient(PLStream *pls, short *xa, short *ya, PLINT npts):&#160;cairo.c'],['../svg_8c.html#ad222a60fa169028ba99ca1475ece14b6',1,'gradient(PLStream *, short *, short *, PLINT):&#160;svg.c']]],
  ['gradient_5fdefined',['gradient_defined',['../plgradient_8c.html#a549c53642fcefbc220bf4ef09e90a158',1,'plgradient.c']]],
  ['gradient_5findex',['gradient_index',['../structSVG.html#a1478ed065a8ac15a5ac5c7f3c03ce991',1,'SVG']]],
  ['graphics_5fanti_5faliasing',['graphics_anti_aliasing',['../structPLCairo.html#aaea63861125bfc78fd2d8e2f00d5fab4',1,'PLCairo::graphics_anti_aliasing()'],['../cairo_8c.html#a34b1934fb70098cfce56e45d2a44ea0e',1,'graphics_anti_aliasing():&#160;cairo.c']]],
  ['graphics_5fmode',['GRAPHICS_MODE',['../plplotP_8h.html#a44b886efaaef4628af9bdc4afc66568e',1,'plplotP.h']]],
  ['graphicsin',['graphicsIn',['../structMemoryMapHeader.html#ae4905de4351f1c48da7b902a5cca0920',1,'MemoryMapHeader']]],
  ['graphx',['graphx',['../structPLStream.html#ac97c1d9507b3b316c557f166eca17430',1,'PLStream']]],
  ['grdashline',['grdashline',['../plline_8c.html#abfcbb055d30afb94ba28d601d3472d47',1,'plline.c']]],
  ['green',['green',['../structcdImageStruct.html#afdfee0cfe98ddb62dd049d97c6285695',1,'cdImageStruct::green()'],['../plstream_8h.html#af38a775b953a654b78d0f13cf899f38bad0784a3f969fe736e8b271a5a161d106',1,'Green():&#160;plstream.h']]],
  ['grey',['Grey',['../plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba068417ac670c285e34e6e63a898e129b',1,'plstream.h']]],
  ['grfill',['grfill',['../plcore_8c.html#a859a0f4ec99bc066171dda65bbd7172c',1,'grfill(short *x, short *y, PLINT npts):&#160;plcore.c'],['../plcore_8h.html#a77d9cf615432469a524b7bc2dd14aeef',1,'grfill(short *, short *, PLINT):&#160;plcore.h']]],
  ['grgradient',['grgradient',['../plcore_8c.html#a7498b6e873f50e540504be66a4e8dde0',1,'grgradient(short *x, short *y, PLINT npts):&#160;plcore.c'],['../plcore_8h.html#a56859b60f4eb1d9be698cfd7e1b02941',1,'grgradient(short *, short *, PLINT):&#160;plcore.h']]],
  ['grid_5fbox',['grid_box',['../plbox_8c.html#ae3bc5f7905a6f76d3fd131d609cd066a',1,'plbox.c']]],
  ['grid_5fcsa',['GRID_CSA',['../plplot_8h.html#a5fbcfaa3170cb529bf1635ff609a78fa',1,'GRID_CSA():&#160;plplot.h'],['../namespaceplplot.html#ac7e8d796ea6f9dd2556a6212cdf0dba7',1,'plplot::GRID_CSA()'],['../namespaceplplotc.html#a00dc056fe56ebe194647cbd1162e343c',1,'plplotc.GRID_CSA()']]],
  ['grid_5fdtli',['GRID_DTLI',['../plplot_8h.html#abeff949898412780654cf7cca55561b2',1,'GRID_DTLI():&#160;plplot.h'],['../namespaceplplot.html#a69350e251c909eb5d9dc20469b532bcb',1,'plplot::GRID_DTLI()'],['../namespaceplplotc.html#ac14adf4dbaa8066db6c3ba43dcb3e2f8',1,'plplotc.GRID_DTLI()']]],
  ['grid_5fnnaidw',['GRID_NNAIDW',['../plplot_8h.html#ac863b08f442af857a166e36ad4721058',1,'GRID_NNAIDW():&#160;plplot.h'],['../namespaceplplot.html#a14854e59f92a3552380e29a55d06622f',1,'plplot::GRID_NNAIDW()'],['../namespaceplplotc.html#ac3170cbecddcf4693801fffa3d313993',1,'plplotc.GRID_NNAIDW()'],['../plgridd_8c.html#ae4e0ce809ddd71b6c228526472fb9f6d',1,'grid_nnaidw():&#160;plgridd.c']]],
  ['grid_5fnni',['GRID_NNI',['../plplot_8h.html#a52d6e7517c3ffac5a0e8a71bdfbc261c',1,'GRID_NNI():&#160;plplot.h'],['../namespaceplplot.html#aae7efb1735fa85ed208db2d57f2d0b48',1,'plplot::GRID_NNI()'],['../namespaceplplotc.html#a8ce11df5f81041361d9a7da90c273424',1,'plplotc.GRID_NNI()']]],
  ['grid_5fnnidw',['GRID_NNIDW',['../plplot_8h.html#aea4b4b399c7eff90105f16be688f869d',1,'GRID_NNIDW():&#160;plplot.h'],['../namespaceplplot.html#a1acbbb4c8a1b2da431aafe9b0383a8d1',1,'plplot::GRID_NNIDW()'],['../namespaceplplotc.html#ad49fbf71d1599309e9d51e5f7abb0f85',1,'plplotc.GRID_NNIDW()'],['../plgridd_8c.html#ac16cb8893c332bd2ebf6f98cddbe1510',1,'grid_nnidw():&#160;plgridd.c']]],
  ['grid_5fnnli',['GRID_NNLI',['../plplot_8h.html#adb70a2b8a3cc84206d433e80e79162f2',1,'GRID_NNLI():&#160;plplot.h'],['../namespaceplplot.html#ae46f869cff5269e5ddac49fbf11f8ff5',1,'plplot::GRID_NNLI()'],['../namespaceplplotc.html#ac3ae103afcb084bddb043b6ab48b552b',1,'plplotc.GRID_NNLI()'],['../plgridd_8c.html#a4f700a1dd26e440d0371d26e7cf12366',1,'grid_nnli():&#160;plgridd.c']]],
  ['griddata',['griddata',['../classplstream.html#a2463e096bfd2fe60b6dd319ef864ffe3',1,'plstream']]],
  ['grimage',['grimage',['../plimage_8c.html#a3bb953b941f306756707370648093b64',1,'grimage(short *x, short *y, unsigned short *z, PLINT nx, PLINT ny):&#160;plimage.c'],['../plplotP_8h.html#a3bb953b941f306756707370648093b64',1,'grimage(short *x, short *y, unsigned short *z, PLINT nx, PLINT ny):&#160;plimage.c']]],
  ['grline',['grline',['../plcore_8c.html#a05047fa1f14551c0664c4d5192eb4b1a',1,'grline(short *x, short *y, PLINT PL_UNUSED(npts)):&#160;plcore.c'],['../plcore_8h.html#a04aa64064f4f9a6a73a3f357c802f88f',1,'grline(short *, short *, PLINT):&#160;plcore.h']]],
  ['grpolyline',['grpolyline',['../plcore_8c.html#a1dd1a3d65c1c7e9912c5da15e82f1ba6',1,'grpolyline(short *x, short *y, PLINT npts):&#160;plcore.c'],['../plcore_8h.html#ae519b27a5fc4ac160aef3b40276c689f',1,'grpolyline(short *, short *, PLINT):&#160;plcore.h']]],
  ['gspa',['gspa',['../classplstream.html#a39425564833b970cfb7987060afd94b8',1,'plstream']]],
  ['gver',['gver',['../classplstream.html#ade99a4b58c7604335b8baeda1b523c8e',1,'plstream']]],
  ['gvpd',['gvpd',['../classplstream.html#af535642162f734a6f85c4e228dc95df3',1,'plstream']]],
  ['gvpw',['gvpw',['../classplstream.html#a6d6bf3dc926030de4a2b44844af52ab3',1,'plstream']]],
  ['gxax',['gxax',['../classplstream.html#aaf7d4d814315a499c635bdc14fe7535e',1,'plstream']]],
  ['gyax',['gyax',['../classplstream.html#af1032c66cea9f4c8137539eb6f0958ea',1,'plstream']]],
  ['gzax',['gzax',['../classplstream.html#a8e9997fb8b145695d4addef62ea90f71',1,'plstream']]]
];
